@@ -74,12 +74,7 @@ private Q_SLOTS:
         const auto jsonRes = Location::toJson(res);
 
         const auto ref = QJsonDocument::fromJson(Test::readFile(refFileName)).array();
-
-        if (jsonRes != ref) {
-            qDebug().noquote() << QJsonDocument(jsonRes).toJson();
-        }
-        QVERIFY(!jsonRes.empty());
-        QCOMPARE(jsonRes, ref);
+        QVERIFY(Test::compareJson(refFileName, jsonRes, ref));
     }
 
     void testParseLocationByName_data()
@@ -105,12 +100,7 @@ private Q_SLOTS:
         const auto jsonRes = Location::toJson(res);
 
         const auto ref = QJsonDocument::fromJson(Test::readFile(refFileName)).array();
-
-        if (jsonRes != ref) {
-            qDebug().noquote() << QJsonDocument(jsonRes).toJson();
-        }
-        QVERIFY(!jsonRes.empty());
-        QCOMPARE(jsonRes, ref);
+        QVERIFY(Test::compareJson(refFileName, jsonRes, ref));
     }
 
     void testParseDepartures_data()
@@ -133,12 +123,7 @@ private Q_SLOTS:
         const auto jsonRes = Stopover::toJson(res);
 
         const auto ref = QJsonDocument::fromJson(Test::readFile(refFileName)).array();
-
-        if (jsonRes != ref) {
-            qDebug().noquote() << QJsonDocument(jsonRes).toJson();
-        }
-        QVERIFY(!jsonRes.empty());
-        QCOMPARE(jsonRes, ref);
+        QVERIFY(Test::compareJson(refFileName, jsonRes, ref));
     }
 
     void testParseJourney_data()
