@@ -95,6 +95,7 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "3", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
     // same as above, containing product, line number and journey number
     { "A", "4", IgnoreRemark, Feature::NoFeature, Feature::Unknown },
+    { "A", "A4", FeatureRemark, Feature::Toilet, Feature::Available },
     { "A", "BO", FeatureRemark, Feature::Restaurant, Feature::Available },
     { "A", "BR", FeatureRemark, Feature::Restaurant, Feature::Available },
     { "A", "BT", FeatureRemark, Feature::Restaurant, Feature::Available },
@@ -162,6 +163,14 @@ static constexpr const RemarkData remarks_map[] = {
     { "A", "bW", FeatureRemark, Feature::BikeStorage, Feature::Conditional },
     { "A", "bf", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "bg", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    { "A", "bq", FeatureRemark, Feature::BikeStorage, Feature::Limited },
+    { "A", "br", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    { "A", "bs", FeatureRemark, Feature::WheelchairAccessibleToilet, Feature::Available },
+    { "A", "bv", FeatureRemark, Feature::WiFi, Feature::Available },
+    { "A", "cc", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
+    { "A", "cd", FeatureRemark, Feature::BikeStorage, Feature::Limited },
+    { "A", "cg", FeatureRemark, Feature::BikeStorage, Feature::Conditional },
+    { "A", "cj", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "de", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
     { "A", "df", FeatureRemark, Feature::WheelchairAccessible, Feature::Unavailable },
     { "A", "dg", FeatureRemark, Feature::WheelchairAccessible, Feature::Available },
