@@ -106,12 +106,12 @@ struct {
 } static constexpr const otp_mode_map[] = {
     { "AIRPLANE", "air", Line::Air },
     { "BUS", "bus", Line::Bus },
-    { "CABLE_CAR", "cableway", Line::Tramway },
+    { "CABLE_CAR", "cableway", Line::AerialLift },
     { "CARPOOL", nullptr, Line::RideShare },
     { "COACH", "coach", Line::Coach },
     { "FERRY", "water", Line::Ferry },
     { "FUNICULAR", "funicular", Line::Funicular },
-    { "GONDOLA", "lift", Line::Tramway },
+    { "GONDOLA", "lift", Line::AerialLift },
     { "RAIL", "rail", Line::LongDistanceTrain },
     { "RAIL", "rail", Line::Train },
     { "RAIL", "rail", Line::LocalTrain },
